 /*
 Turnstile Access Control System
 by Gift Nyathikazi
 */  
#include <MFRC522.h>       // library for RFID 
#include <SPI.h>           // library that convert pin (11,12,13) to (MOSI, MISO, SCK)
#include <Stepper.h>       // include stepper library

//Stepper motor drive to arduino connection
int IN1 = 5;
int IN2 = 6;
int IN3 = 7;
int IN4 = 8;
// the number of steps in one revolution of stepper motor (28BYJ-48)
int revolution = 2038;    
// the correct stepping order for the stepper motor (28BYJ-48)
Stepper stepper(revolution, IN1, IN3, IN2, IN4);

//RFID SDA & RST pins to arduino pins
int SDA_pin = 10; 
int RST_pin = 9; 
MFRC522 mfrc522(SDA_pin, RST_pin); 

int IR = 2;               //IR sensor signal pin

void setup() {                      
  //setting Step Motor driver pins as OUTPUT
  pinMode(IN1, OUTPUT);
  pinMode(IN2, OUTPUT);
  pinMode(IN3, OUTPUT);
  pinMode(IN4, OUTPUT);
  
  pinMode(IR, INPUT);   //set IR as INPUT
  mfrc522.PCD_Init();   //Initializes the MFRC522 chip.
  SPI.begin();          //Setting SCK, MOSI, and MISO to outputs
  Serial.begin(9600);   //Set up serial communication
}

void loop() {   
int detect = digitalRead(IR); //Read the IR digital pin

//wait for the card/tag to be near the sensor
if ( ! mfrc522.PICC_IsNewCardPresent()){
return;
}

//read the identity number of the card/tag
if ( ! mfrc522.PICC_ReadCardSerial()) {
return;
}

Serial.print("Tag:");
String content= "";
for (byte i = 0; i < mfrc522.uid.size; i++) {
//card/tag Identity number convertions to Hex
content.concat(String(mfrc522.uid.uidByte[i] < 0x10 ? " 0" : " "));
content.concat(String(mfrc522.uid.uidByte[i], HEX)); 

//Write the card/tag hex to serial monitor
Serial.print(mfrc522.uid.uidByte[i] < 0x10 ? " 0" : " ");
Serial.print(mfrc522.uid.uidByte[i], HEX);
}

content.toUpperCase();
content = content.substring(1);

//IF the card/tag is correct and IR detect a person you enter
if((content == "A9 6D ED B8" || content == "E9 CC F1 71" || content == "17 C6 DF 73") && detect == LOW){
 stepper.setSpeed(14);        // 18 is max working speed for this step motor
 stepper.step(revolution/4);  // rotate motor 509.5 steps (90 degree) anti-clockwise
 delay(1000);                 // wait one second 
}

//IF the card/tag is correct and IR doesn't detect a person you exit
else if((content == "A9 6D ED B8" || content == "E9 CC F1 71" || content == "17 C6 DF 73") && detect == HIGH){
 stepper.setSpeed(14);        
 stepper.step(-revolution/4);   // rotate motor 90 degree clockwise 
 delay(1000);
}
 
else{
//do nothing 
}
Serial.println();
}
     
 
